Class: Richcss::VersionKit::Set

Inherits:
Object
  • Object
show all
Defined in:
lib/richcss/vendor/version_kit/lib/version_kit/set.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, versions) ⇒ Set

Returns a new instance of Set.

Parameters:

  • name (String)

    the name of the Pod.

  • sources (Array<Source>, Source)

    the sources that contain a Pod.



20
21
22
23
# File 'lib/richcss/vendor/version_kit/lib/version_kit/set.rb', line 20

def initialize(name, versions)
  @name = name
  @versions = Array(versions)
end

Instance Attribute Details

#nameString (readonly)

Returns the name of the Pod.

Returns:

  • (String)

    the name of the Pod.



7
8
9
# File 'lib/richcss/vendor/version_kit/lib/version_kit/set.rb', line 7

def name
  @name
end

#versionsArray<Source> (readonly)

Returns the sources that contain the specifications for the available versions of a Pod.

Returns:

  • (Array<Source>)

    the sources that contain the specifications for the available versions of a Pod.



12
13
14
# File 'lib/richcss/vendor/version_kit/lib/version_kit/set.rb', line 12

def versions
  @versions
end