Class: Richcss::VersionKit::Set
- Inherits:
-
Object
- Object
- Richcss::VersionKit::Set
- Defined in:
- lib/richcss/vendor/version_kit/lib/version_kit/set.rb
Instance Attribute Summary collapse
-
#name ⇒ String
readonly
The name of the Pod.
-
#versions ⇒ Array<Source>
readonly
The sources that contain the specifications for the available versions of a Pod.
Instance Method Summary collapse
-
#initialize(name, versions) ⇒ Set
constructor
A new instance of Set.
Constructor Details
#initialize(name, versions) ⇒ Set
Returns a new instance of Set.
20 21 22 23 |
# File 'lib/richcss/vendor/version_kit/lib/version_kit/set.rb', line 20 def initialize(name, versions) @name = name @versions = Array(versions) end |
Instance Attribute Details
#name ⇒ String (readonly)
Returns the name of the Pod.
7 8 9 |
# File 'lib/richcss/vendor/version_kit/lib/version_kit/set.rb', line 7 def name @name end |
#versions ⇒ Array<Source> (readonly)
Returns the sources that contain the specifications for the available versions of a Pod.
12 13 14 |
# File 'lib/richcss/vendor/version_kit/lib/version_kit/set.rb', line 12 def versions @versions end |